@@ -110,6 +110,8 @@ randomNoW <- function(graph, verbose=FALSE)
 #' @param ... additional parameters to use with any of the previous described 
 #' methods (see igraph package community detection methods for more details 
 #' i.e. \link[igraph]{cluster_walktrap})
+#' @param leiden_objective_function objective_function parameter for leiden only
+#'  for method
 #' @param FUN in case the @method parameter is "other" there is the possibility 
 #' to use a personal function passing its name through this parameter.
 #' The personal parameter has to take as input the @graph and the @weights 
@@ -129,6 +131,7 @@ methodCommunity <- function(graph,
                                     "fastGreedy", "louvain", "spinglass", 
                                     "leadingEigen", "labelProp", "infomap",
                                     "optimal", "leiden", "other"), 
+                            leiden_objective_function=c("modularity","CPM"), 
                                     ..., FUN=NULL, verbose=FALSE)
 {   
     
@@ -145,7 +148,7 @@ methodCommunity <- function(graph,
             fastGreedy=igraph::cluster_fast_greedy(graph=graph, ...), 
             labelProp=igraph::cluster_label_prop(graph=graph, ...), 
             infomap=igraph::cluster_infomap(graph=graph, ...),
-            leiden=igraph::cluster_leiden(graph=graph, ...),
+            leiden=igraph::cluster_leiden(graph=graph, objective_function=leiden_objective_function,...),
             other=FUN(graph, ...)
     )
     return(communities)
